@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IBaseMailboxFolders_VERSION = "4.1.56826"
+IBaseMailboxFolders_VERSION = "4.1.56917"
 
 class IBaseMailboxFolders(BaseEndpoint):
     def __init__(self, apiKey, url ):
@@ -151,6 +151,18 @@ class IBaseMailboxFolders(BaseEndpoint):
         from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
         from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
         return self.handleResult__(__ContainerChangelogSerDer__(), response)
+    def root (self):
+        postUri = "/_root";
+        __data__ = None
+        __encoded__ = None
+        queryParams = {  };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IBaseMailboxFolders_VERSION}, data = __encoded__);
+        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
+        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__MailboxFolderSerDer__()), response)
     def searchItems (self, query ):
         postUri = "/_search";
         __data__ = None
