@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IMailboxFoldersByContainer_VERSION = "4.1.56826"
+IMailboxFoldersByContainer_VERSION = "4.1.56917"
 
 class IMailboxFoldersByContainer(BaseEndpoint):
     def __init__(self, apiKey, url ,container ):
@@ -119,6 +119,18 @@ class IMailboxFoldersByContainer(BaseEndpoint):
 
         response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFoldersByContainer_VERSION}, data = __encoded__);
         return self.handleResult__(None, response)
+    def root (self):
+        postUri = "/_root";
+        __data__ = None
+        __encoded__ = None
+        queryParams = {  };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFoldersByContainer_VERSION}, data = __encoded__);
+        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
+        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__MailboxFolderSerDer__()), response)
     def getCompleteById (self, id ):
         postUri = "/{id}/completeById";
         __data__ = None
